#!/usr/bin/sudo bash

set -e

CURR_VER=$1
OLD_RPMS=($2)
IS_RETRY=$3
LOGGER="logger -s -p local6.info -t $CURR_VER"
RPM_NAME="TCR"
DEB_NAME="tcr"
DIR_PREFIX="tcr"
BIN_NAME="tcrd"

if grep -q "^ID=ubuntu" /etc/os-release ; then
    IS_UBUNTU=1
    PIDOF='/usr/bin/pidof'
else
    IS_UBUNTU=0
    PIDOF='/sbin/pidof'
fi

if [ $IS_UBUNTU -eq 0 ]; then
    if rpm -qa TOP* | grep -qw TOP; then
        RPM_NAME="TOP"
        BIN_NAME="topd"
        DIR_PREFIX="top"
    fi
else
    if dpkg --list top* | grep -qw top ; then
        DEB_NAME="top"
        BIN_NAME="topd"
        DIR_PREFIX="top"
    fi
fi

function wanproxy_shm_umount() {
    for path in `mount | grep "wanproxy/dev/shm" | awk ' { print $3 } '`;
    do
      echo "$0: Going to umount: $path" | xargs $LOGGER;
      umount -l -f $path 2>&1 | xargs $LOGGER;
    done
}

function remove_old_rpms() {
    if [ ${#OLD_RPMS[@]} -eq 0 ]; then
        echo "$0: No RPM versions supplied" 2>&1 | xargs $LOGGER 
        exit 1
    fi

    for ver in "${OLD_RPMS[@]}";
    do
        RPM_VER="$RPM_NAME-$ver-1-1.x86_64"
        DEB_VER="$DEB_NAME-$ver"

        if $PIDOF watchdog-$ver > /dev/null 2>&1; then
            if [ $IS_UBUNTU -eq 0 ]; then
                echo "$0: $RPM_VER version is running, stopping the service" 2>&1 | xargs $LOGGER
            else
                echo "$0: $DEB_VER version is running, stopping the service" 2>&1 | xargs $LOGGER
            fi
            /opt/$DIR_PREFIX-$ver/$BIN_NAME stop
        fi
        
        # Uninstall RPM
        if [ $IS_UBUNTU -eq 0 ]; then
            /usr/bin/rpm -e $RPM_VER 2>&1 | xargs $LOGGER
        else
            /usr/bin/dpkg --purge $DEB_VER 2>&1 | xargs -0 $LOGGER
        fi

        # Verify un-installation
        if [ $IS_UBUNTU -eq 0 ]; then
            if ! /usr/bin/rpm -qa | /usr/bin/grep -q $RPM_VER; then
                echo "$0: RPM version $RPM_VER uninstalled successfully" 2>&1 | xargs $LOGGER
            else
                echo "$0: Could not uninstall RPM version $RPM_VER" 2>&1 | xargs $LOGGER
            fi
        else
            if ! dpkg --list $DEB_VER &> /dev/null ; then
                echo "$0: DEB version $DEB_VER uninstalled successfully" 2>&1 | xargs $LOGGER
            else
                echo "$0: Could not uninstall DEB version $DEB_VER" 2>&1 | xargs $LOGGER
            fi
        fi
    done
}

if [ "$#" -ne 2 ]; then
    echo "$0: Illegal number of parameters"
    exit 1
fi

wanproxy_shm_umount
remove_old_rpms

